@@ -44,6 +44,34 @@ my @TEST_PCS = (
         strict           => 1,
         non_geographical => 0,
     },
+    {   raw              => 'SE1',
+        area             => 'SE',
+        district         => '1',
+        subdistrict      => undef,
+        sector           => undef,
+        unit             => undef,
+        outcode          => 'SE1',
+        incode           => '',
+        fixed_format     => 'SE1     ',
+        valid            => 1,
+        partial          => 1,
+        strict           => 1,
+        non_geographical => 0,
+    },
+    {   raw              => 'SE1 0LH',
+        area             => 'SE',
+        district         => '1',
+        subdistrict      => undef,
+        sector           => '0',
+        unit             => 'LH',
+        outcode          => 'SE1',
+        incode           => '0LH',
+        fixed_format     => 'SE1  0LH',
+        valid            => 1,
+        partial          => 0,
+        strict           => 1,
+        non_geographical => 0,
+    },
     {   raw              => 'WC1H 9',
         area             => 'WC',
         district         => '1',
@@ -72,6 +100,21 @@ my @TEST_PCS = (
         strict           => 1,
         non_geographical => 1,
     },
+    {   raw              => 'BF1 1AA',
+        area             => 'BF',
+        district         => '1',
+        subdistrict      => undef,
+        sector           => '1',
+        unit             => 'AA',
+        outcode          => 'BF1',
+        incode           => '1AA',
+        fixed_format     => 'BF1  1AA',
+        valid            => 1,
+        partial          => 0,
+        strict           => 1,
+        non_geographical => 1,
+        bfpo             => 1,
+    },
 );
 
 sub test_pcs {
